@@ -79,7 +79,7 @@ def n2o_cluster(country):
   plt.ylabel('k t', fontsize=12)
   plt.legend(fontsize=15)
   plt.grid()
-  plt.savefig('./results/result_n2o.png')
+  plt.savefig('../results/result_n2o.png')
   plt.show()
 
 
